##
##  restic.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg  0.17.2
%define       V_dist  20241028

#   package information
Name:         restic
Summary:      Backup Utility
URL:          https://restic.github.io/
Vendor:       Alexander Neumann
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Filesystem
License:      MIT
Version:      %{V_opkg}.%{V_dist}
Release:      20241028

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/restic/restic-%{V_dist}.tar.xz
Patch0:       restic.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    restic(1) is a Unix backup program that is fast, efficient and
    secure. It supports snapshots and can store backups locally, or
    remotely on an SFTP or AWS/Minio S3 storage. Additionally, it can
    use rclone(1) as its storage backend and this way access over 30
    cloud storage providers, too.

%track
    prog restic:release = {
        version   = %{V_opkg}
        url       = https://github.com/restic/restic/releases
        regex     = tree/v(\d+\.\d+\.\d+)
    }
    prog restic:snapshot = {
        version   = %{V_dist}
        url       = http://download.openpkg.org/components/versioned/restic/
        regex     = restic-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n restic
    %patch -p0

%build
    #   build program
    export GOPATH=`pwd`
    export HOME=`pwd`
    cd src/github.com/restic/restic
    go run build.go -v

%install
    #   install program
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1
    %{l_shtool} install -c -s -m 755 \
        src/github.com/restic/restic/restic \
        $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 644 \
        src/github.com/restic/restic/doc/man/*.1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

